@@ -5,23 +5,34 @@ use warnings;
 
 use base qw(HTML::Widgets::NavMenu::Iterator::Html);
 
-sub start_root
+=head1 NAME
+
+HTML::Widgets::NavMenu::Iterator::Html - an iterator for HTML.
+
+=head1 SYNOPSIS
+
+For internal use only.
+
+=head1 METHODS
+=cut
+
+sub _start_root
 {
     my $self = shift;
     
     $self->_add_tags("<ul>");
 }
 
-sub start_sep
+sub _start_sep
 {
 }
 
-sub start_regular
+sub _start_regular
 {
     my $self = shift;
 
     my $top_item = $self->top;
-    my $node = $self->top->node();
+    my $node = $self->top->_node();
 
     my $nav_menu = $self->{'nav_menu'};
 
@@ -34,20 +45,28 @@ sub start_regular
     }
     $self->_add_tags($tag);
 
-    if ($top_item->num_subs_to_go())
+    if ($top_item->_num_subs_to_go())
     {
         $self->_add_tags("<br />");
         $self->_add_tags("<ul>");
     }
 }
 
-sub end_sep
+sub _end_sep
 {
 }
 
-sub is_expanded
+sub _is_expanded
 {
     return 1;
 }
 
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2006 Shlomi Fish, all rights reserved.
+
+This program is released under the following license: MIT X11.
+
+=cut
+
 1;
