@@ -50,10 +50,22 @@ sub _is_dir
 }
 
 sub _get_relative_url
+{
+    my $base = shift;
+
+    my $url = $base->_get_url_worker(@_);
+
+    return ( ($url eq "") ? "./" : $url);
+}
+
+sub _get_url_worker
 {
     my $base = shift;
     my $to = shift;
     my $slash_terminated = shift;
+    my $no_leading_dot = shift;
+
+    my $prefix = ($no_leading_dot ? "" : "./");
 
     my @this_url = @{$base->_get_url()};
     my @other_url = @{$to->_get_url()};
@@ -83,7 +95,7 @@ sub _get_relative_url
         {
             if (scalar(@this_url_bak))
             {
-                return "./" . $this_url_bak[-1];
+                return $prefix . $this_url_bak[-1];
             }
             else
             {
@@ -103,7 +115,7 @@ sub _get_relative_url
     {
         if ((scalar(@this_url) == 0) && (scalar(@other_url) == 0))
         {
-            $ret = "./";
+            $ret = $prefix;
         }
         else
         {
@@ -121,7 +133,7 @@ sub _get_relative_url
     else
     {
         my @components = ((map { ".." } @this_url[1..$#this_url]), @other_url);
-        $ret .= ("./" . join("/", @components)); 
+        $ret .= ($prefix . join("/", @components)); 
         if (($to->_is_dir()) && ($base->{'mode'} ne "harddisk") && scalar(@components))
         {
             $ret .= "/";
